@@ -1,13 +1,16 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2016 by Dominique Dumont.
+# This software is Copyright (c) 2015-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-[
+use strict;
+use warnings;
+
+return [
   {
     'accept' => [
       '.*',
@@ -42,11 +45,11 @@ L<systemd.resource-control(5)>,
 which configure resource control settings for the processes of the
 socket.
 
-For each socket file, a matching service file must exist,
+For each socket unit, a matching service unit must exist,
 describing the service to start on incoming traffic on the socket
 (see
 L<systemd.service(5)>
-for more information about .service files). The name of the
+for more information about .service units). The name of the
 .service unit is by default the same as the name of the .socket
 unit, but can be altered with the C<Service> option
 described below. Depending on the setting of the
@@ -54,23 +57,14 @@ C<Accept> option described below, this .service
 unit must either be named like the .socket unit, but with the
 suffix replaced, unless overridden with C<Service>;
 or it must be a template unit named the same way. Example: a
-socket file foo.socket needs a matching
-service foo.service if
-C<Accept=false> is set. If
-C<Accept=true> is set, a service template file
-foo@.service must exist from which services
+socket file C<foo.socket> needs a matching
+service C<foo.service> if
+C<Accept=no> is set. If
+C<Accept=yes> is set, a service template
+C<foo@.service> must exist from which services
 are instantiated for each incoming connection.
 
-Unless C<DefaultDependencies> in the C<[Unit]> section is set to
-C<false>, socket units will implicitly have dependencies of type C<Requires> and
-C<After> on sysinit.target as well as dependencies of type
-C<Conflicts> and C<Before> on shutdown.target. These ensure
-that socket units pull in basic system initialization, and are terminated cleanly prior to system shutdown. Only
-sockets involved with early boot or late system shutdown should disable this option.
-
-Socket units will have a C<Before>
-dependency on the service which they trigger added implicitly. No
-implicit C<WantedBy> or
+No implicit C<WantedBy> or
 C<RequiredBy> dependency from the socket to the
 service is added. This means that the service may be started
 without the socket, in which case it must be able to open sockets
@@ -81,16 +75,24 @@ Socket units may be used to implement on-demand starting of
 services, as well as parallelized starting of services. See the
 blog stories linked at the end for an introduction.
 
-Note that the daemon software configured for socket
-activation with socket units needs to be able to accept sockets
-from systemd, either via systemd\'s native socket passing interface
-(see
-L<sd_listen_fds(3)>
-for details) or via the traditional
-L<inetd(8)>-style
-socket passing (i.e. sockets passed in via standard input and
-output, using C<StandardInput=socket> in the
-service file).
+Note that the daemon software configured for socket activation with socket units needs to be able
+to accept sockets from systemd, either via systemd\'s native socket passing interface (see
+L<sd_listen_fds(3)> for
+details about the precise protocol used and the order in which the file descriptors are passed) or via
+traditional L<inetd(8)>-style
+socket passing (i.e. sockets passed in via standard input and output, using
+C<StandardInput=socket> in the service file).
+
+All network sockets allocated through C<.socket> units are allocated in the host\'s network
+namespace (see L<network_namespaces(7)>). This
+does not mean however that the service activated by a configured socket unit has to be part of the host\'s network
+namespace as well.  It is supported and even good practice to run services in their own network namespace (for
+example through C<PrivateNetwork>, see
+L<systemd.exec(5)>), receiving only
+the sockets configured through socket-activation from the host\'s namespace. In such a set-up communication within
+the host\'s network namespace is only permitted through the activation sockets passed in while all sockets allocated
+from the service code itself will be associated with the service\'s own namespace, and thus possibly subject to a a
+much more restrictive configuration.
 This configuration class was generated from systemd documentation.
 by L<parse-man.pl|https://github.com/dod38fr/config-model-systemd/contrib/parse-man.pl>
 ',
@@ -130,13 +132,24 @@ in the service being available via both IPv6 and IPv4
 (default) or just via IPv6.
 
 If the address string is a string in the format
-v.w.x.y:z, it is read as IPv4 specifier for listening on an
-address v.w.x.y on a port z.
+C<v.w.x.y:z>, it is interpreted
+as IPv4 address v.w.x.y and port z.
 
-If the address string is a string in the format [x]:y,
-it is read as IPv6 address x on a port y. Note that this might
-make the service available via IPv4, too, depending on the
-C<BindIPv6Only> setting (see below).
+If the address string is a string in the format
+C<[x]:y>, it is interpreted as
+IPv6 address x and port y. An optional
+interface scope (interface name or number) may be specified after a C<%> symbol:
+C<[x]:y%dev>.
+Interface scopes are only useful with link-local addresses, because the kernel ignores them in other
+cases. Note that if an address is specified as IPv6, it might still make the service available via
+IPv4 too, depending on the C<BindIPv6Only> setting (see below).
+
+If the address string is a string in the format
+C<vsock:x:y>, it is read as CID
+x on a port y address in the
+C<AF_VSOCK> family.  The CID is a unique 32-bit integer identifier in
+C<AF_VSOCK> analogous to an IP address.  Specifying the CID is optional, and may be
+set to the empty string.
 
 Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
@@ -201,13 +214,24 @@ in the service being available via both IPv6 and IPv4
 (default) or just via IPv6.
 
 If the address string is a string in the format
-v.w.x.y:z, it is read as IPv4 specifier for listening on an
-address v.w.x.y on a port z.
+C<v.w.x.y:z>, it is interpreted
+as IPv4 address v.w.x.y and port z.
 
-If the address string is a string in the format [x]:y,
-it is read as IPv6 address x on a port y. Note that this might
-make the service available via IPv4, too, depending on the
-C<BindIPv6Only> setting (see below).
+If the address string is a string in the format
+C<[x]:y>, it is interpreted as
+IPv6 address x and port y. An optional
+interface scope (interface name or number) may be specified after a C<%> symbol:
+C<[x]:y%dev>.
+Interface scopes are only useful with link-local addresses, because the kernel ignores them in other
+cases. Note that if an address is specified as IPv6, it might still make the service available via
+IPv4 too, depending on the C<BindIPv6Only> setting (see below).
+
+If the address string is a string in the format
+C<vsock:x:y>, it is read as CID
+x on a port y address in the
+C<AF_VSOCK> family.  The CID is a unique 32-bit integer identifier in
+C<AF_VSOCK> analogous to an IP address.  Specifying the CID is optional, and may be
+set to the empty string.
 
 Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
@@ -272,13 +296,24 @@ in the service being available via both IPv6 and IPv4
 (default) or just via IPv6.
 
 If the address string is a string in the format
-v.w.x.y:z, it is read as IPv4 specifier for listening on an
-address v.w.x.y on a port z.
+C<v.w.x.y:z>, it is interpreted
+as IPv4 address v.w.x.y and port z.
 
-If the address string is a string in the format [x]:y,
-it is read as IPv6 address x on a port y. Note that this might
-make the service available via IPv4, too, depending on the
-C<BindIPv6Only> setting (see below).
+If the address string is a string in the format
+C<[x]:y>, it is interpreted as
+IPv6 address x and port y. An optional
+interface scope (interface name or number) may be specified after a C<%> symbol:
+C<[x]:y%dev>.
+Interface scopes are only useful with link-local addresses, because the kernel ignores them in other
+cases. Note that if an address is specified as IPv6, it might still make the service available via
+IPv4 too, depending on the C<BindIPv6Only> setting (see below).
+
+If the address string is a string in the format
+C<vsock:x:y>, it is read as CID
+x on a port y address in the
+C<AF_VSOCK> family.  The CID is a unique 32-bit integer identifier in
+C<AF_VSOCK> analogous to an IP address.  Specifying the CID is optional, and may be
+set to the empty string.
 
 Note that C<SOCK_SEQPACKET> (i.e.
 C<ListenSequentialPacket>) is only available
@@ -314,28 +349,36 @@ below.',
       },
       'ListenFIFO',
       {
-        'description' => 'Specifies a file system FIFO to listen on.
-This expects an absolute file system path as argument.
-Behavior otherwise is very similar to the
-C<ListenDatagram> directive
-above.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Specifies a file system FIFO (see L<fifo(7)> for
+details) to listen on.  This expects an absolute file system path as argument.  Behavior otherwise is
+very similar to the C<ListenDatagram> directive above.',
+        'type' => 'list'
       },
       'ListenSpecial',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => 'Specifies a special file in the file system to
 listen on. This expects an absolute file system path as
 argument. Behavior otherwise is very similar to the
 C<ListenFIFO> directive above. Use this to
 open character device nodes as well as special files in
-/proc and
-/sys.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+C</proc/> and
+C</sys/>.',
+        'type' => 'list'
       },
       'ListenNetlink',
       {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
         'description' => 'Specifies a Netlink family to create a socket
 for to listen on. This expects a short string referring to the
 C<AF_NETLINK> family name (such as
@@ -344,48 +387,61 @@ as argument, optionally suffixed by a whitespace followed by a
 multicast group integer. Behavior otherwise is very similar to
 the C<ListenDatagram> directive
 above.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'ListenMessageQueue',
       {
-        'description' => 'Specifies a POSIX message queue name to listen
-on. This expects a valid message queue name (i.e. beginning
-with /). Behavior otherwise is very similar to the
-C<ListenFIFO> directive above. On Linux
-message queue descriptors are actually file descriptors and
-can be inherited between processes.',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Specifies a POSIX message queue name to listen on (see L<mq_overview(7)>
+for details). This expects a valid message queue name (i.e. beginning with
+C</>). Behavior otherwise is very similar to the C<ListenFIFO>
+directive above. On Linux message queue descriptors are actually file descriptors and can be
+inherited between processes.',
+        'type' => 'list'
       },
       'ListenUSBFunction',
       {
-        'description' => 'Specifies a USB
-FunctionFS endpoints location to listen on, for
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'Specifies a L<USB
+FunctionFS|https://www.kernel.org/doc/Documentation/usb/functionfs.txt> endpoints location to listen on, for
 implementation of USB gadget functions. This expects an
-absolute file system path of functionfs mount point as the argument.
+absolute file system path of a FunctionFS mount point as the argument.
 Behavior otherwise is very similar to the C<ListenFIFO>
 directive above. Use this to open the FunctionFS endpoint
-ep0. When using this option, the
+C<ep0>. When using this option, the
 activated service has to have the
 C<USBFunctionDescriptors> and
 C<USBFunctionStrings> options set.
 ',
-        'type' => 'leaf',
-        'value_type' => 'uniline'
+        'type' => 'list'
       },
       'SocketProtocol',
       {
-        'description' => 'Takes a one of C<udplite>
-or C<sctp>. Specifies a socket protocol
-(C<IPPROTO_UDPLITE>) UDP-Lite
-(C<IPPROTO_SCTP>) SCTP socket respectively. ',
+        'choice' => [
+          'udplite',
+          'sctp'
+        ],
+        'description' => 'Takes one of C<udplite>
+or C<sctp>. The socket will use the UDP-Lite
+(C<IPPROTO_UDPLITE>) or SCTP
+(C<IPPROTO_SCTP>) protocol, respectively.',
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'enum'
       },
       'BindIPv6Only',
       {
-        'description' => 'Takes a one of C<default>,
+        'choice' => [
+          'default',
+          'both',
+          'ipv6-only'
+        ],
+        'description' => 'Takes one of C<default>,
 C<both> or C<ipv6-only>. Controls
 the IPV6_V6ONLY socket option (see
 L<ipv6(7)>
@@ -395,11 +451,11 @@ C<ipv6-only>, they will be accessible via IPv6
 only. If C<default> (which is the default,
 surprise!), the system wide default setting is used, as
 controlled by
-/proc/sys/net/ipv6/bindv6only, which in
+C</proc/sys/net/ipv6/bindv6only>, which in
 turn defaults to the equivalent of
 C<both>.',
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'enum'
       },
       'Backlog',
       {
@@ -414,39 +470,33 @@ for details. Defaults to SOMAXCONN (128).',
       },
       'BindToDevice',
       {
-        'description' => 'Specifies a network interface name to bind
-this socket to. If set, traffic will only be accepted from the
-specified network interfaces. This controls the
-SO_BINDTODEVICE socket option (see L<socket(7)>
-for details). If this option is used, an automatic dependency
-from this socket unit on the network interface device unit
-(L<systemd.device(5)>
-is created. Note that setting this parameter might result in
-additional dependencies to be added to the unit (see
+        'description' => 'Specifies a network interface name to bind this socket to. If set, traffic will only
+be accepted from the specified network interfaces. This controls the
+C<SO_BINDTODEVICE> socket option (see L<socket(7)> for
+details). If this option is used, an implicit dependency from this socket unit on the network
+interface device unit is created
+(see L<systemd.device(5)>).
+Note that setting this parameter might result in additional dependencies to be added to the unit (see
 above).',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'SocketUser',
       {
-        'description' => 'Takes a UNIX user/group name. When specified,
-all AF_UNIX sockets and FIFO nodes in the file system are
-owned by the specified user and group. If unset (the default),
-the nodes are owned by the root user/group (if run in system
-context) or the invoking user/group (if run in user context).
-If only a user is specified but no group, then the group is
+        'description' => 'Takes a UNIX user/group name. When specified, all C<AF_UNIX>
+sockets and FIFO nodes in the file system are owned by the specified user and group. If unset (the
+default), the nodes are owned by the root user/group (if run in system context) or the invoking
+user/group (if run in user context).  If only a user is specified but no group, then the group is
 derived from the user\'s default group.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'SocketGroup',
       {
-        'description' => 'Takes a UNIX user/group name. When specified,
-all AF_UNIX sockets and FIFO nodes in the file system are
-owned by the specified user and group. If unset (the default),
-the nodes are owned by the root user/group (if run in system
-context) or the invoking user/group (if run in user context).
-If only a user is specified but no group, then the group is
+        'description' => 'Takes a UNIX user/group name. When specified, all C<AF_UNIX>
+sockets and FIFO nodes in the file system are owned by the specified user and group. If unset (the
+default), the nodes are owned by the root user/group (if run in system context) or the invoking
+user/group (if run in user context).  If only a user is specified but no group, then the group is
 derived from the user\'s default group.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -472,36 +522,36 @@ notation. Defaults to 0755.',
       },
       'Accept',
       {
-        'description' => 'Takes a boolean argument. If true, a service
+        'description' => 'Takes a boolean argument. If yes, a service
 instance is spawned for each incoming connection and only the
-connection socket is passed to it. If false, all listening
+connection socket is passed to it. If no, all listening
 sockets themselves are passed to the started service unit, and
 only one service unit is spawned for all connections (also see
 above). This value is ignored for datagram sockets and FIFOs
 where a single service unit unconditionally handles all
-incoming traffic. Defaults to C<false>. For
+incoming traffic. Defaults to C<no>. For
 performance reasons, it is recommended to write new daemons
 only in a way that is suitable for
-C<Accept=false>. A daemon listening on an
+C<Accept=no>. A daemon listening on an
 C<AF_UNIX> socket may, but does not need to,
 call
 L<close(2)>
 on the received socket before exiting. However, it must not
 unlink the socket from a file system. It should not invoke
 L<shutdown(2)>
-on sockets it got with C<Accept=false>, but it
+on sockets it got with C<Accept=no>, but it
 may do so for sockets it got with
-C<Accept=true> set. Setting
-C<Accept=true> is mostly useful to allow
+C<Accept=yes> set. Setting
+C<Accept=yes> is mostly useful to allow
 daemons designed for usage with
 L<inetd(8)>
 to work unmodified with systemd socket
 activation.
 
-For IPv4 and IPv6 connections, the C<REMOTE_ADDR>
-environment variable will contain the remote IP address, and C<REMOTE_PORT>
-will contain the remote port. This is the same as the format used by CGI.
-For SOCK_RAW, the port is the IP protocol.',
+For IPv4 and IPv6 connections, the C<REMOTE_ADDR> environment variable will
+contain the remote IP address, and C<REMOTE_PORT> will contain the remote port. This
+is the same as the format used by CGI. For C<SOCK_RAW>, the port is the IP
+protocol.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -522,15 +572,32 @@ false, in read-only mode. Defaults to false.',
           'yes'
         ]
       },
+      'FlushPending',
+      {
+        'description' => 'Takes a boolean argument. May only be used when
+C<Accept=no>. If yes, the socket\'s buffers are cleared after the
+triggered service exited. This causes any pending data to be
+flushed and any pending incoming connections to be rejected. If no, the
+socket\'s buffers won\'t be cleared, permitting the service to handle any
+pending connections after restart, which is the usually expected behaviour.
+Defaults to C<no>.
+',
+        'type' => 'leaf',
+        'value_type' => 'boolean',
+        'write_as' => [
+          'no',
+          'yes'
+        ]
+      },
       'MaxConnections',
       {
         'description' => 'The maximum number of connections to
 simultaneously run services instances for, when
-C<Accept=true> is set. If more concurrent
+C<Accept=yes> is set. If more concurrent
 connections are coming in, they will be refused until at least
 one existing connection is terminated. This setting has no
 effect on sockets configured with
-C<Accept=false> or datagram sockets. Defaults to
+C<Accept=no> or datagram sockets. Defaults to
 64.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -545,16 +612,12 @@ above. Disabled by default.',
       },
       'KeepAlive',
       {
-        'description' => 'Takes a boolean argument. If true, the TCP/IP
-stack will send a keep alive message after 2h (depending on
-the configuration of
-/proc/sys/net/ipv4/tcp_keepalive_time)
-for all TCP streams accepted on this socket. This controls the
-SO_KEEPALIVE socket option (see
-L<socket(7)>
-and the TCP
-Keepalive HOWTO for details.) Defaults to
-C<false>.',
+        'description' => 'Takes a boolean argument. If true, the TCP/IP stack will send a keep alive message
+after 2h (depending on the configuration of
+C</proc/sys/net/ipv4/tcp_keepalive_time>) for all TCP streams accepted on this
+socket. This controls the C<SO_KEEPALIVE> socket option (see L<socket(7)> and
+the L<TCP Keepalive
+HOWTO|http://www.tldp.org/HOWTO/html_single/TCP-Keepalive-HOWTO/> for details.) Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -568,22 +631,19 @@ C<false>.',
 idle before TCP starts sending keepalive probes. This controls the TCP_KEEPIDLE
 socket option (see
 L<socket(7)>
-and the TCP
-Keepalive HOWTO for details.)
+and the L<TCP
+Keepalive HOWTO|http://www.tldp.org/HOWTO/html_single/TCP-Keepalive-HOWTO/> for details.)
 Defaults value is 7200 seconds (2 hours).',
         'type' => 'leaf',
         'value_type' => 'integer'
       },
       'KeepAliveIntervalSec',
       {
-        'description' => 'Takes time (in seconds) as argument between
-individual keepalive probes, if the socket option SO_KEEPALIVE
-has been set on this socket. This controls
-the TCP_KEEPINTVL socket option (see
-L<socket(7)>
-and the TCP
-Keepalive HOWTO for details.) Defaults value is 75
-seconds.',
+        'description' => 'Takes time (in seconds) as argument between individual keepalive probes, if the
+socket option C<SO_KEEPALIVE> has been set on this socket. This controls the
+C<TCP_KEEPINTVL> socket option (see L<socket(7)> and
+the L<TCP Keepalive
+HOWTO|http://www.tldp.org/HOWTO/html_single/TCP-Keepalive-HOWTO/> for details.) Defaults value is 75 seconds.',
         'type' => 'leaf',
         'value_type' => 'integer'
       },
@@ -594,8 +654,8 @@ unacknowledged probes to send before considering the
 connection dead and notifying the application layer. This
 controls the TCP_KEEPCNT socket option (see
 L<socket(7)>
-and the TCP
-Keepalive HOWTO for details.) Defaults value is
+and the L<TCP
+Keepalive HOWTO|http://www.tldp.org/HOWTO/html_single/TCP-Keepalive-HOWTO/> for details.) Defaults value is
 9.',
         'type' => 'leaf',
         'value_type' => 'integer'
@@ -606,7 +666,7 @@ Keepalive HOWTO for details.) Defaults value is
 algorithm works by combining a number of small outgoing
 messages, and sending them all at once. This controls the
 TCP_NODELAY socket option (see
-L<tcp(7)>
+L<tcp(7)>).
 Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
@@ -617,11 +677,9 @@ Defaults to C<false>.',
       },
       'Priority',
       {
-        'description' => 'Takes an integer argument controlling the
-priority for all traffic sent from this socket. This controls
-the SO_PRIORITY socket option (see
-L<socket(7)>
-for details.).',
+        'description' => 'Takes an integer argument controlling the priority for all traffic sent from this
+socket. This controls the C<SO_PRIORITY> socket option (see L<socket(7)> for
+details.).',
         'type' => 'leaf',
         'value_type' => 'integer'
       },
@@ -655,74 +713,61 @@ Disabled by default.',
       },
       'ReceiveBuffer',
       {
-        'description' => 'Takes an integer argument controlling the
-receive or send buffer sizes of this socket, respectively.
-This controls the SO_RCVBUF and SO_SNDBUF socket options (see
-L<socket(7)>
-for details.). The usual suffixes K, M, G are supported and
-are understood to the base of 1024.',
+        'description' => 'Takes an integer argument controlling the receive or send buffer sizes of this
+socket, respectively.  This controls the C<SO_RCVBUF> and
+C<SO_SNDBUF> socket options (see L<socket(7)> for
+details.). The usual suffixes K, M, G are supported and are understood to the base of
+1024.',
         'match' => '^\\d+(?i)[KMG]$',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'SendBuffer',
       {
-        'description' => 'Takes an integer argument controlling the
-receive or send buffer sizes of this socket, respectively.
-This controls the SO_RCVBUF and SO_SNDBUF socket options (see
-L<socket(7)>
-for details.). The usual suffixes K, M, G are supported and
-are understood to the base of 1024.',
+        'description' => 'Takes an integer argument controlling the receive or send buffer sizes of this
+socket, respectively.  This controls the C<SO_RCVBUF> and
+C<SO_SNDBUF> socket options (see L<socket(7)> for
+details.). The usual suffixes K, M, G are supported and are understood to the base of
+1024.',
         'match' => '^\\d+(?i)[KMG]$',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
       'IPTOS',
       {
-        'description' => 'Takes an integer argument controlling the IP
-Type-Of-Service field for packets generated from this socket.
-This controls the IP_TOS socket option (see
-L<ip(7)>
-for details.). Either a numeric string or one of
-C<low-delay>, C<throughput>,
-C<reliability> or C<low-cost> may
-be specified.',
+        'description' => 'Takes an integer argument controlling the IP Type-Of-Service field for packets
+generated from this socket.  This controls the C<IP_TOS> socket option (see
+L<ip(7)> for
+details.). Either a numeric string or one of C<low-delay>, C<throughput>,
+C<reliability> or C<low-cost> may be specified.',
         'type' => 'leaf',
         'value_type' => 'integer'
       },
       'IPTTL',
       {
-        'description' => 'Takes an integer argument controlling the IPv4
-Time-To-Live/IPv6 Hop-Count field for packets generated from
-this socket. This sets the IP_TTL/IPV6_UNICAST_HOPS socket
-options (see
-L<ip(7)>
-and
-L<ipv6(7)>
-for details.)',
+        'description' => 'Takes an integer argument controlling the IPv4 Time-To-Live/IPv6 Hop-Count field for
+packets generated from this socket. This sets the
+C<IP_TTL>/C<IPV6_UNICAST_HOPS> socket options (see L<ip(7)> and
+L<ipv6(7)> for
+details.)',
         'type' => 'leaf',
         'value_type' => 'integer'
       },
       'Mark',
       {
-        'description' => 'Takes an integer value. Controls the firewall
-mark of packets generated by this socket. This can be used in
-the firewall logic to filter packets from this socket. This
-sets the SO_MARK socket option. See
-L<iptables(8)>
-for details.',
+        'description' => 'Takes an integer value. Controls the firewall mark of packets generated by this
+socket. This can be used in the firewall logic to filter packets from this socket. This sets the
+C<SO_MARK> socket option. See L<iptables(8)> for
+details.',
         'type' => 'leaf',
         'value_type' => 'integer'
       },
       'ReusePort',
       {
-        'description' => 'Takes a boolean value. If true, allows
-multiple
-L<bind(2)>s
-to this TCP or UDP port. This controls the SO_REUSEPORT socket
-option. See
-L<socket(7)>
-for details.',
+        'description' => 'Takes a boolean value. If true, allows multiple
+L<bind(2)>s to this TCP
+or UDP port. This controls the C<SO_REUSEPORT> socket option. See L<socket(7)> for
+details.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -738,7 +783,7 @@ C<security.SMACK64IPIN> and
 C<security.SMACK64IPOUT>, respectively, i.e.
 the security label of the FIFO, or the security label for the
 incoming or outgoing connections of the socket, respectively.
-See Smack.txt
+See L<Smack.txt|https://www.kernel.org/doc/Documentation/security/Smack.txt>
 for details.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -751,7 +796,7 @@ C<security.SMACK64IPIN> and
 C<security.SMACK64IPOUT>, respectively, i.e.
 the security label of the FIFO, or the security label for the
 incoming or outgoing connections of the socket, respectively.
-See Smack.txt
+See L<Smack.txt|https://www.kernel.org/doc/Documentation/security/Smack.txt>
 for details.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -764,7 +809,7 @@ C<security.SMACK64IPIN> and
 C<security.SMACK64IPOUT>, respectively, i.e.
 the security label of the FIFO, or the security label for the
 incoming or outgoing connections of the socket, respectively.
-See Smack.txt
+See L<Smack.txt|https://www.kernel.org/doc/Documentation/security/Smack.txt>
 for details.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -781,9 +826,9 @@ binary that is effectively triggered by socket unit or from
 the value of the C<SELinuxContext> option.
 This configuration option only affects sockets with
 C<Accept> mode set to
-C<true>. Also note that this option is useful
+C<yes>. Also note that this option is useful
 only when MLS/MCS SELinux policy is deployed. Defaults to
-C<false>. ',
+C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -814,14 +859,12 @@ for details.',
       },
       'FreeBind',
       {
-        'description' => 'Takes a boolean value. Controls whether the
-socket can be bound to non-local IP addresses. This is useful
-to configure sockets listening on specific IP addresses before
-those IP addresses are successfully configured on a network
-interface. This sets the IP_FREEBIND socket option. For
-robustness reasons it is recommended to use this option
-whenever you bind a socket to a specific IP address. Defaults
-to C<false>.',
+        'description' => 'Takes a boolean value. Controls whether the socket can be bound to non-local IP
+addresses. This is useful to configure sockets listening on specific IP addresses before those IP
+addresses are successfully configured on a network interface. This sets the
+C<IP_FREEBIND>/C<IPV6_FREEBIND> socket option. For robustness
+reasons it is recommended to use this option whenever you bind a socket to a specific IP
+address. Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -832,7 +875,7 @@ to C<false>.',
       'Transparent',
       {
         'description' => 'Takes a boolean value. Controls the
-IP_TRANSPARENT socket option. Defaults to
+C<IP_TRANSPARENT>/C<IPV6_TRANSPARENT> socket option. Defaults to
 C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
@@ -843,9 +886,8 @@ C<false>.',
       },
       'Broadcast',
       {
-        'description' => 'Takes a boolean value. This controls the
-SO_BROADCAST socket option, which allows broadcast datagrams
-to be sent from this socket. Defaults to
+        'description' => 'Takes a boolean value. This controls the C<SO_BROADCAST> socket
+option, which allows broadcast datagrams to be sent from this socket. Defaults to
 C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
@@ -856,11 +898,9 @@ C<false>.',
       },
       'PassCredentials',
       {
-        'description' => 'Takes a boolean value. This controls the
-SO_PASSCRED socket option, which allows
-C<AF_UNIX> sockets to receive the
-credentials of the sending process in an ancillary message.
-Defaults to C<false>.',
+        'description' => 'Takes a boolean value. This controls the C<SO_PASSCRED> socket
+option, which allows C<AF_UNIX> sockets to receive the credentials of the sending
+process in an ancillary message. Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -870,11 +910,9 @@ Defaults to C<false>.',
       },
       'PassSecurity',
       {
-        'description' => 'Takes a boolean value. This controls the
-SO_PASSSEC socket option, which allows
-C<AF_UNIX> sockets to receive the security
-context of the sending process in an ancillary message.
-Defaults to C<false>.',
+        'description' => 'Takes a boolean value. This controls the C<SO_PASSSEC> socket
+option, which allows C<AF_UNIX> sockets to receive the security context of the
+sending process in an ancillary message.  Defaults to C<false>.',
         'type' => 'leaf',
         'value_type' => 'boolean',
         'write_as' => [
@@ -882,13 +920,45 @@ Defaults to C<false>.',
           'yes'
         ]
       },
+      'PassPacketInfo',
+      {
+        'description' => 'Takes a boolean value. This controls the C<IP_PKTINFO>,
+C<IPV6_RECVPKTINFO>, C<NETLINK_PKTINFO> or
+C<PACKET_AUXDATA> socket options, which enable reception of additional per-packet
+metadata as ancillary message, on C<AF_INET>, C<AF_INET6>,
+C<AF_UNIX> and C<AF_PACKET> sockets.  Defaults to
+C<false>.',
+        'type' => 'leaf',
+        'value_type' => 'boolean',
+        'write_as' => [
+          'no',
+          'yes'
+        ]
+      },
+      'Timestamping',
+      {
+        'choice' => [
+          'off',
+          'us',
+          'usec',
+          "\x{b5}s",
+          'ns',
+          'nsec'
+        ],
+        'description' => "Takes one of C<off>, C<us> (alias:
+C<usec>, C<\x{b5}s>) or C<ns> (alias:
+C<nsec>). This controls the C<SO_TIMESTAMP> or
+C<SO_TIMESTAMPNS> socket options, and enables whether ingress network traffic shall
+carry timestamping metadata. Defaults to C<off>.",
+        'type' => 'leaf',
+        'value_type' => 'enum'
+      },
       'TCPCongestion',
       {
-        'description' => 'Takes a string value. Controls the TCP
-congestion algorithm used by this socket. Should be one of
-"westwood", "veno", "cubic", "lp" or any other available
-algorithm supported by the IP stack. This setting applies only
-to stream sockets.',
+        'description' => 'Takes a string value. Controls the TCP congestion algorithm used by this
+socket. Should be one of C<westwood>, C<veno>,
+C<cubic>, C<lp> or any other available algorithm supported by the IP
+stack. This setting applies only to stream sockets.',
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
@@ -991,15 +1061,12 @@ above).',
       },
       'RemoveOnStop',
       {
-        'description' => 'Takes a boolean argument. If enabled, any file
-nodes created by this socket unit are removed when it is
-stopped. This applies to AF_UNIX sockets in the file system,
-POSIX message queues, FIFOs, as well as any symlinks to them
-configured with C<Symlinks>. Normally, it
-should not be necessary to use this option, and is not
-recommended as services might continue to run after the socket
-unit has been terminated and it should still be possible to
-communicate with them via their file system node. Defaults to
+        'description' => 'Takes a boolean argument. If enabled, any file nodes created by this socket unit are
+removed when it is stopped. This applies to C<AF_UNIX> sockets in the file system,
+POSIX message queues, FIFOs, as well as any symlinks to them configured with
+C<Symlinks>. Normally, it should not be necessary to use this option, and is not
+recommended as services might continue to run after the socket unit has been terminated and it should
+still be possible to communicate with them via their file system node. Defaults to
 off.',
         'type' => 'leaf',
         'value_type' => 'boolean',
@@ -1010,13 +1077,12 @@ off.',
       },
       'Symlinks',
       {
-        'description' => 'Takes a list of file system paths. The
-specified paths will be created as symlinks to the AF_UNIX
-socket path or FIFO path of this socket unit. If this setting
-is used, only one AF_UNIX socket in the file system or one
-FIFO may be configured for the socket unit. Use this option to
-manage one or more symlinked alias names for a socket, binding
-their lifecycle together. Defaults to the empty
+        'description' => 'Takes a list of file system paths. The specified paths will be created as symlinks to the
+C<AF_UNIX> socket path or FIFO path of this socket unit. If this setting is used, only one
+C<AF_UNIX> socket in the file system or one FIFO may be configured for the socket unit. Use
+this option to manage one or more symlinked alias names for a socket, binding their lifecycle together. Note
+that if creation of a symlink fails this is not considered fatal for the socket unit, and the socket unit may
+still start. If an empty string is assigned, the list of paths is reset. Defaults to an empty
 list.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1033,7 +1099,7 @@ descriptors. Names may contain any ASCII character, but must
 exclude control characters and C<:>, and must
 be at most 255 characters in length. If this setting is not
 used, the file descriptor name defaults to the name of the
-socket unit, including its .socket
+socket unit, including its C<.socket>
 suffix.',
         'type' => 'leaf',
         'value_type' => 'uniline'
@@ -1071,7 +1137,7 @@ limit is enforced before the service activation is enqueued.",
         'value_type' => 'uniline'
       }
     ],
-    'generated_by' => 'parse-man.pl from systemd doc',
+    'generated_by' => 'parse-man.pl from systemd 247 doc',
     'license' => 'LGPLv2.1+',
     'name' => 'Systemd::Section::Socket'
   }
